@@ -4,6 +4,7 @@ from wcd_geo_db.modules.client import CodeSeekingClientMixin, DBClientMixin
 from px_client_builder import NestedClient
 from wcd_geo_db.const import DivisionLevel
 from wcd_geo_db.modules.code_seeker.query import CodeSeekSeq
+from wcd_geo_db.utils import response_with_ordering
 
 from ..query.geometry import Area
 from ..dtos import DivisionDTO, DivisionTranslationDTO
@@ -20,8 +21,16 @@ class DivisionsClient(DBClientMixin, CodeSeekingClientMixin, NestedClient):
     model: Type[Division] = Division
     _qs: DivisionsQuerySet
 
-    def get(self, ids: Sequence[int]) -> Sequence[DivisionDTO]:
-        return self._qs.general_filter(ids=ids).as_dtos()
+    def get(self, ids: Sequence[int], keep_ordering: bool = False) -> Sequence[DivisionDTO]:
+        if keep_ordering:
+            ids = list(ids)
+
+        response = self._qs.general_filter(ids=ids).as_dtos()
+
+        if keep_ordering:
+            response = response_with_ordering(ids, response)
+
+        return response
 
     def get_by_code(self, code: str, value: Any) -> Sequence[DivisionDTO]:
         return self.get(self.find(self._qs, codes=((code, value),)))
