@@ -1,12 +1,11 @@
 from django.db import models
 from django.contrib.postgres.fields import ArrayField
-from django.contrib.postgres.indexes import GinIndex
 from django.utils.translation import pgettext_lazy
 
 
 __all__ = (
-    'create_types_field', 'create_division_field', 'codes_indexes',
-    'CodesDefinableMixin', 'GroupingMixin', 'NamedMixin',
+    'create_types_field', 'create_division_field',
+    'GroupingMixin', 'NamedMixin',
 )
 
 
@@ -31,28 +30,6 @@ def create_division_field(**kw):
     )
 
 
-
-def codes_indexes():
-    return [
-        GinIndex(
-            name='%(app_label)s_%(class)s_codes_idx',
-            fields=['codes'],
-            opclasses=('jsonb_ops',)
-        ),
-    ]
-
-
-class CodesDefinableMixin(models.Model):
-    class Meta:
-        abstract = True
-        indexes = codes_indexes()
-
-    codes = models.JSONField(
-        verbose_name=pgettext_lazy('wcd_geo_db', 'Codes'),
-        null=False, blank=True, default=dict
-    )
-
-
 class GroupingMixin(models.Model):
     class Meta:
         abstract = True
